pub struct Error<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized = NoContext> { /* private fields */ }Expand description
Represents errors that occur when the value of type T does not satisfy the predicate P.
The context C provides additional information about the error, and defaults to NoContext.
For instance, False expects nothing and its code is false, so the error message is:
expected nothing (no context) [false]Implementations