Refinement

Struct Refinement 

pub struct Refinement<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized = NoContext> { /* private fields */ }
Represents refinement types.

Implementations

Source

impl<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>

pub const unsafe fn unchecked_ref(value: &T) -> &Self

Constructs Self by reference without checking.

Safety

This method should only be called for references that satisfy P, which can be checked via is_fine.

pub fn get_ref(&self) -> &T

Returns the contained value reference.

If the unsafe-assert feature is enabled, assert_unchecked is called on the reference before returning.

The get_ref_no_assert method is provided in case the assertion is explicitly not needed.

pub const fn get_ref_no_assert(&self) -> &T

Returns the contained value.

pub fn is_fine(value: &T) -> bool

Checks whether the provided value satisfies P.

This is the same as calling P::check on it.

pub fn checked_ref(value: &T) -> RecoverableRef<'_, Self, P, C, T>

Constructs Self by reference.

Errors

Returns Error<T, P, C> in case the reference does not satisfy P.

Source

impl<T, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>

pub const unsafe fn unchecked(value: T) -> Self

Constructs Self without checking the value.

Safety

This method should only be called for values that satisfy the predicate P, which can be checked using is_fine.

pub fn get(self) -> T

Returns the contained value.

If the unsafe-assert feature is enabled, assert_unchecked is called on the reference before returning the value.

The get_no_assert method is provided in case the assertion is explicitly not needed.

pub fn get_no_assert(self) -> T

Returns the contained value.

pub fn checked(value: T) -> Recoverable<Self, P, C, T>

Constructs Self from the given value.

Errors

Returns Error<T, P, C> in case the value does not satisfy P.