Check

Trait Check 

pub trait Check {
    // Provided method
    fn satisfies<P: Predicate<Self> + ?Sized>(&self) -> bool { ... }
}
Extends any type T to check whether values satisfy given Predicate<T>.

Provided Methods

fn satisfies<P: Predicate<Self> + ?Sized>(&self) -> bool

Checks whether the Self value satisfies the given predicate.

This method calls P::check in its implementation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: ?Sized> Check for T