pub struct Refinement<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized = NoContext> { /* private fields */ }Expand description
Represents refinement types.
Implementations
Sourceimpl<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>
impl<T: ?Sized, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>
Sourcepub const unsafe fn unchecked_ref(value: &T) -> &Self
pub const unsafe fn unchecked_ref(value: &T) -> &Self
Sourcepub fn get_ref(&self) -> &T
pub fn get_ref(&self) -> &T
Returns the contained value reference.
If the unsafe-assert feature is enabled, assert_unchecked is called on the reference
before returning.
The get_ref_no_assert method is provided in case the assertion is explicitly not needed.
Sourcepub const fn get_ref_no_assert(&self) -> &T
pub const fn get_ref_no_assert(&self) -> &T
Returns the contained value.
Sourcepub fn is_fine(value: &T) -> bool
pub fn is_fine(value: &T) -> bool
Checks whether the provided value satisfies P.
This is the same as calling P::check on it.
Sourcepub fn checked_ref(value: &T) -> RecoverableRef<'_, Self, P, C, T>
pub fn checked_ref(value: &T) -> RecoverableRef<'_, Self, P, C, T>
Constructs Self by reference.
Errors
Returns Error<T, P, C> in case the reference does not satisfy P.
Sourceimpl<T, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>
impl<T, P: Predicate<T> + ?Sized, C: TypeStr + ?Sized> Refinement<T, P, C>
Sourcepub fn get(self) -> T
pub fn get(self) -> T
Returns the contained value.
If the unsafe-assert feature is enabled, assert_unchecked is called on the reference
before returning the value.
The get_no_assert method is provided in case the assertion is explicitly not needed.
Sourcepub fn get_no_assert(self) -> T
pub fn get_no_assert(self) -> T
Returns the contained value.
Sourcepub fn checked(value: T) -> Recoverable<Self, P, C, T>
pub fn checked(value: T) -> Recoverable<Self, P, C, T>
Constructs Self from the given value.
Errors
Returns Error<T, P, C> in case the value does not satisfy P.